@@ -22,7 +22,7 @@ static const double INVEPS = 1/DBL_EPSILON;
 static R_INLINE double x_d_omx(double x) {
     if (x < 0 || x > 1)
   // # nocov start    
-	error(_("Value %lf out of range (0, 1)"), x);
+	error("Value %lf out of range (0, 1)", x);
   // # nocov end  
     return x/(1 - x);
 }
@@ -192,7 +192,8 @@ double binomial_loglik(double *Y, double*mu, double *wts, double devb, int n) {
   double ll = 0.0;
 
   for (i = 0; i < n; i++) {
-    ll += wts[i]*dbinom(Y[i],1.0,mu[i],1);
+//    ll += wts[i]*dbinom(Y[i],1.0,mu[i],1);
+     ll += wts[i]*(Y[i]*log(x_d_omx(mu[i])) + log(1.0 - mu[i]));
   }
   return(ll);
 }
@@ -291,7 +292,7 @@ double binomial_dispersion(double *resid,  double *weights, int n, int rank) {
 void binomial_initialize(double *Y, double *mu,  double *weights, int n) {
   int i;
   for (i = 0; i < n; i++) {
-    if (weights[1] == 0) Y[i] = 0.0;
+    if (weights[i] == 0) Y[i] = 0.0;
     mu[i] = (weights[i] * Y[i] + 0.5)/(weights[i] + 1.0) ;
   }
 }
@@ -391,9 +392,9 @@ void  Lapack_chol2inv(double *A, int sz, double *ans)
 	F77_CALL(dpotri)("U", &sz, &ans[0], &sz, &i FCONE);
 	if (i != 0) {
 	    if (i > 0)  // # nocov start
-		error(_("element (%d, %d) is zero, so the inverse cannot be computed"),
+		error("element (%d, %d) is zero, so the inverse cannot be computed",
 		      i, i);
-	    error(_("argument %d of Lapack routine %s had invalid value"),
+	    error("argument %d of Lapack routine %s had invalid value",
 		  -i, "dpotri");  // # nocov end
 	}
 
