@@ -51,7 +51,19 @@ SEXP glm_deterministic(SEXP Y, SEXP X, SEXP Roffset, SEXP Rweights,
 	SEXP sampleprobs = PROTECT(allocVector(REALSXP, nModels)); ++nProtected;
 	SEXP Q = PROTECT(allocVector(REALSXP, nModels)); ++nProtected;
 	SEXP Rintercept = PROTECT(allocVector(REALSXP, nModels)); ++nProtected;
-
+	
+	memset(REAL(modelprobs), 0.0, sizeof(double) *nModels);
+	memset(REAL(priorprobs), 0.0, sizeof(double) *nModels);
+	memset(REAL(shrinkage), 0.0, sizeof(double) *nModels);
+	memset(REAL(logmarg), 0.0, sizeof(double) *nModels);
+	memset(REAL(sampleprobs), 0.0, sizeof(double) *nModels);
+	memset(REAL(R2), 0.0, sizeof(double) *nModels);
+	memset(REAL(Q), 0.0, sizeof(double) *nModels);
+	memset(REAL(Rintercept), 0.0, sizeof(double) *nModels);
+	memset(REAL(deviance), 0.0, sizeof(double) *nModels);
+	memset(INTEGER(modeldim), 0, sizeof(int) *nModels);
+	
+;
 	double *probs,shrinkage_m,logmargy;
 
 	//get dimsensions of all variables
