@@ -103,7 +103,16 @@ extern SEXP sampleworep_new(SEXP Y, SEXP X, SEXP Rweights, SEXP Rprobinit,
 	
 	setAttrib(ANS, R_NamesSymbol, ANS_names);
 	
-	
+	memset(REAL(Rlogmarg), 0.0, sizeof(double) *nModels);
+	memset(REAL(modelprobs), 0.0, sizeof(double) *nModels);
+	memset(REAL(priorprobs), 0.0, sizeof(double) *nModels);
+	memset(REAL(shrinkage), 0.0, sizeof(double) *nModels);
+	memset(REAL(R2), 0.0, sizeof(double) *nModels);
+	memset(REAL(Rlogmarg), 0.0, sizeof(double) *nModels);
+	memset(REAL(sampleprobs), 0.0, sizeof(double) *nModels);
+	memset(INTEGER(modeldim), 0, sizeof(int) *nModels);
+	memset(REAL(mse), 0.0, sizeof(double) *nModels);
+	memset(INTEGER(rank), 0, sizeof(int) *nModels);	
 
 	//  Rprintf("Allocating Space for %d Models\n", nModels) ;
 	/* Allocate Space for Results  R < 4.5.2
